"""
isoddeven - A fun Python package to find out if a number is odd or even vouched at https://mewtru.com/is-odd
"""

from .isoddeven import is_odd
from .isoddeven import is_odd
from .isoddeven import state
from .extras import is_up
from .extras import about



import requests
import json

def is_odd(n: int) -> bool:
    response = requests.get(f"https://is-odd-api.mewtru.com/v1/numbers/{n}")
    json_data = json.loads(response.text)
    state = json_data["state"]
    if state == "odd":
        return True
    else:
        return False

def is_even(n: int) -> bool:
    response = requests.get(f"https://is-odd-api.mewtru.com/v1/numbers/{n}")
    json_data = json.loads(response.text)
    state = json_data["state"]
    if state == "even":
        return True
    else:
        return False

def state(n: int) -> str:
    response = requests.get(f"https://is-odd-api.mewtru.com/v1/numbers/{n}")
    json_data = json.loads(response.text)
    state = json_data["state"]
    return state



from setuptools import setup, find_packages

setup(
    name='isoddeven',
    version='0.1.0',
    # description='A fun Python package to find out if a number is odd or even vouched at mewtru.com/is-odd',
    author='Nilay Sarma',
    packages=find_packages(),
    install_requires=["requests"],
    license="MIT"
)